abacusai.document_retriever_lookup_result — AbacusAI documentation

# `abacusai.document_retriever_lookup_result`

## Module Contents

### Classes

`DocumentRetrieverLookupResult` | Result of a document retriever lookup.

class abacusai.document_retriever_lookup_result.DocumentRetrieverLookupResult(client, document=None, score=None, properties=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Result of a document retriever lookup.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - document (str) – The document that was looked up.

    - score (float) – Score of the document with respect to the query.

    - properties (dict) – Properties of the retrieved documents.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict